@@ -49,7 +49,7 @@ const SAFE_NODE_EXECUTABLE: &str = "sn_node.exe";
 
 const BASE_TRACING_DIRECTIVES: &str = "testnet=info,sn_launch_tool=debug";
 const NODES_DIR: &str = "local-test-network";
-const INTERVAL: Duration = Duration::from_secs(2);
+const INTERVAL: Duration = Duration::from_millis(100);
 const DEFAULT_NODE_COUNT: u32 = 33;
 
 #[derive(Debug, StructOpt)]
@@ -142,7 +142,7 @@ pub async fn run_network() -> Result<()> {
     let node_count_str = node_count.to_string();
 
     // Let's create an args array to pass to the network launcher tool
-    let interval_str = INTERVAL.as_secs().to_string();
+    let interval_str = INTERVAL.as_millis().to_string();
     let mut sn_launch_tool_args = vec![
         "sn_launch_tool",
         "--node-path",
