@@ -17,6 +17,7 @@ use crate::routing::{
     dkg::SectionAuthUtils,
     ed25519,
     error::{Error, Result},
+    log_markers::LogMarker,
     messages::WireMsgUtils,
     node::Node,
     peer::PeerUtils,
@@ -260,6 +261,8 @@ impl JoiningAsRelocated {
             self.genesis_key,
         )?;
 
+        trace!("{}", LogMarker::SendJoinRequest);
+
         let cmd = Command::SendMessage {
             recipients: recipients.to_vec(),
             wire_msg,
