@@ -14,6 +14,7 @@ use crate::messaging::{
 use crate::routing::{
     dkg::SectionAuthUtils,
     error::{Error, Result},
+    log_markers::LogMarker,
     messages::WireMsgUtils,
     routing_api::command::Command,
     SectionAuthorityProviderUtils,
@@ -131,6 +132,7 @@ impl Core {
                 // from the received new SAP key, to prevent from endlessly resending a msg
                 // if a sybil/corrupt peer keeps sending us the same AE msg.
                 let dst_section_pk = section_auth.public_key_set.public_key();
+                trace!("{}", LogMarker::ResendAfterAeRetry);
                 let cmd =
                     self.send_direct_message((src_name, sender), bounced_msg, dst_section_pk)?;
                 Ok(vec![cmd])
@@ -205,6 +207,7 @@ impl Core {
                 );
                 Ok(vec![])
             } else {
+                trace!("{}", LogMarker::AeResendAfterAeRedirect);
                 let cmd = self.send_direct_message((*name, *addr), bounced_msg, dst_section_pk)?;
                 Ok(vec![cmd])
             }
@@ -217,6 +220,7 @@ impl Core {
             // For the situation non-elder exists in both incoming and local SAP, send to one of
             // the incoming elder with the geneis key to trigger AE.
             if let Some((name, addr)) = section_auth.elders.iter().next() {
+                trace!("{}", LogMarker::BounceAfterNewElderNotKnownLocally);
                 let cmd = self.send_direct_message(
                     (*name, *addr),
                     bounced_msg,
@@ -266,6 +270,7 @@ impl Core {
                         ae_msg,
                         self.section.authority_provider().section_key(),
                     )?;
+                    trace!("{}", LogMarker::AeSendRedirect);
 
                     return Ok(Some(Command::SendMessage {
                         recipients: vec![(src_location.name(), sender)],
@@ -321,6 +326,8 @@ impl Core {
                 let section_signed = section_signed_auth.sig;
                 let bounced_msg = original_bytes;
 
+                trace!("{}", LogMarker::AeSendRetryAsOutdated);
+
                 SystemMsg::AntiEntropyRetry {
                     section_auth,
                     section_signed,
@@ -342,6 +349,8 @@ impl Core {
                 let section_signed = section_signed_auth.sig;
                 let bounced_msg = original_bytes;
 
+                trace!("{}", LogMarker::AeSendRetryDstPkFail);
+
                 SystemMsg::AntiEntropyRetry {
                     section_auth,
                     section_signed,
@@ -388,6 +397,8 @@ impl Core {
             self.section.authority_provider().section_key(),
         )?;
 
+        trace!("{} in ae_redirect", LogMarker::AeSendRedirect);
+
         Ok(Command::SendMessage {
             recipients: vec![(src_location.name(), sender)],
             wire_msg,
