@@ -11,6 +11,7 @@ use crate::messaging::system::{JoinResponse, Peer, ResourceProofResponse, System
 use crate::routing::{
     core::{RESOURCE_PROOF_DATA_SIZE, RESOURCE_PROOF_DIFFICULTY},
     ed25519,
+    log_markers::LogMarker,
     peer::PeerUtils,
     routing_api::command::Command,
     Error, Result,
@@ -56,6 +57,7 @@ impl Core {
             nonce_signature: ed25519::sign(&serialized, &self.node.keypair),
         }));
 
+        trace!("{}", LogMarker::SendResourceProofChallenge);
         self.send_direct_message(
             (*peer.name(), *peer.addr()),
             response,
