@@ -6,18 +6,13 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-#[cfg(test)]
-use strum_macros::EnumIter;
-
 // this gets us to_string easily enough
-#[cfg(test)]
-use strum_macros::Display as StrumDisplay;
+use strum_macros::{Display as StrumDisplay, EnumIter, EnumString};
 
 /// Internal log marker, to be used in tests asserts.
-#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone)]
-#[cfg_attr(test, derive(EnumIter, StrumDisplay))]
+#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Clone, EnumIter, StrumDisplay, EnumString)]
 #[allow(missing_docs)]
-pub(crate) enum LogMarker {
+pub enum LogMarker {
     ServiceMsgToBeHandled,
     SystemMsgToBeHandled,
     StoringChunk,
@@ -34,4 +29,25 @@ pub(crate) enum LogMarker {
     CommandHandleStart,
     CommandHandleEnd,
     CommandHandleError,
+    PromotedToElder,
+    DemotedFromElder,
+    DkgSendFailureObservation,
+    DkgBroadcastMsg,
+    ResendAfterAeRetry,
+    AeResendAfterAeRedirect,
+    BounceAfterNewElderNotKnownLocally,
+    SendingAeUpdateAfterLagCheck,
+    AeSendRedirect,
+    AeSendRetryAsOutdated,
+    AeSendRetryDstPkFail,
+    SendJoinRequest,
+    SendOrHandle,
+    SendDirect,
+    SendDirectToNodes,
+    SendResourceProofChallenge,
+    SendJoinAsRelocatedResponse,
+    SendJoinRejected,
+    SendJoinRetry,
+    SendJoinsDisallowed,
+    SendNodeApproval,
 }
